/**
 *
 */
package de.intevation.gnv.artifacts;

import java.io.FileOutputStream;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

/**
 * @author Tim Englich <tim.englich@intevation.de>
 *
 */
public class MeshHorizontalProfileTestCase extends GNVArtifactsTestCaseBase {

    private static Logger log = Logger.getLogger(MeshHorizontalProfileTestCase.class);
    
    /**
     * Constructor
     */
    public MeshHorizontalProfileTestCase() {
    }

    /**
     * Constructor
     * @param name
     */
    public MeshHorizontalProfileTestCase(String name) {
        super(name);
    }

    /**
     * @see de.intevation.gnv.artifacts.GNVArtifactsTestCaseBase#testArtifact()
     */
    @Override
    public void testArtifact() {
        try {
            log.debug("GNVArtifactsTestCase." +
                      "testHorizontalProfileInstantaneousPointArtifact");
            String artefactName = "fis_modeldata";
            ArtifactFactory artifactFactory = this
                    .getArtifactFactory(artefactName);
            assertNotNull(artifactFactory);
            log.debug("VerticalProfile-ArtifactFactory is available");
            
            Artifact artifact = createArtifact(artifactFactory);

            CallContext cc = createCallContext(artifactFactory);
            Document describeDocument = this.readDocument("src/test/ressources/horizontalProfile_mesh/horizontalprofile_describe.xml");
            
            int steps = 11;
            
            for (int i = 1; i <= steps; i++){
                String number = ""+i;
                if (i < 10){
                    number = "0"+number;
                }
                this.doNextStep(
                            artifact,
                            cc,
                            "src/test/ressources/horizontalProfile_mesh/" +
                            "horizontalprofile_step_"+number+"_feed.xml",
                            "src/test/ressources/horizontalProfile_mesh/" +
                            "horizontalprofile_step_"+number+"_advance.xml", 
                            describeDocument);
            }
            
            Document outputData = artifact.describe(describeDocument,cc);
            FileOutputStream fos = null;
            FileOutputStream fos2 = null;
            FileOutputStream fos3 = null;
            FileOutputStream fos4 = null;
            try {
                fos = new FileOutputStream(
                        "src/test/results/horizontalProfile_mesh"
                                + System.currentTimeMillis() + ".png");
                fos2 = new FileOutputStream(
                        "src/test/results/horizontalProfile_mesh"
                                + System.currentTimeMillis() + ".xml");
                fos3 = new FileOutputStream(
                        "src/test/results/horizontalProfile_mesh"
                                + System.currentTimeMillis() + ".csv");
                fos4 = new FileOutputStream(
                        "src/test/results/horizontalProfile_mesh"
                                + System.currentTimeMillis() + ".odv");
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_mesh/" +
                                               "horizontalprofile_step_"+steps+"_out_statistics.xml"),
                             fos2, cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_mesh/" +
                                               "horizontalprofile_step_"+steps+"_out_chart.xml"),
                                fos, cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_mesh/" +
                                               "horizontalprofile_step_"+steps+"_out_csv.xml"),
                             fos3, cc);
                artifact.out(this.readDocument("src/test/ressources/" +
                                               "horizontalProfile_mesh/" +
                                               "horizontalprofile_step_"+steps+"_out_odv.xml"),
                             fos4, cc);
            } catch (Exception e) {
                log.error(e, e);
                fail();
            } finally {
                try {
                    fos.flush();
                    fos.close();
                    fos2.flush();
                    fos2.close();
                    fos3.flush();
                    fos3.close();
                    fos4.flush();
                    fos4.close();
                } catch (Exception e) {
                    log.error(e, e);
                }
            }
        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
